Binary

Trait Binary 

1.36.0 · Source
pub trait Binary {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
b formatting.

The Binary trait should format its output as a number in binary.

For primitive signed integers (i8 to i128, and isize), negative values are formatted as the two’s complement representation.

The alternate flag, #, adds a 0b in front of the output.

For more information on formatters, see the module-level documentation.

Examples

Basic usage with i32:

let x = 42; // 42 is '101010' in binary

assert_eq!(format!("{x:b}"), "101010");
assert_eq!(format!("{x:#b}"), "0b101010");

assert_eq!(format!("{:b}", -16), "11111111111111111111111111110000");

Implementing Binary on a type:

use std::fmt;

struct Length(i32);

impl fmt::Binary for Length {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        let val = self.0;

        fmt::Binary::fmt(&val, f) // delegate to i32's implementation
    }
}

let l = Length(107);

assert_eq!(format!("l as binary is: {l:b}"), "l as binary is: 1101011");

assert_eq!(
    // Note that the `0b` prefix added by `#` is included in the total width, so we
    // need to add two to correctly display all 32 bits.
    format!("l as binary is: {l:#034b}"),
    "l as binary is: 0b00000000000000000000000001101011"
);

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Implementors

1.0.0 · Source

impl Binary for i8

1.0.0 · Source

impl Binary for i16

1.0.0 · Source

impl Binary for i32

1.0.0 · Source

impl Binary for i64

1.0.0 · Source

impl Binary for i128

1.0.0 · Source

impl Binary for isize

1.0.0 · Source

impl Binary for u8

1.0.0 · Source

impl Binary for u16

1.0.0 · Source

impl Binary for u32

1.0.0 · Source

impl Binary for u64

1.0.0 · Source

impl Binary for u128

1.0.0 · Source

impl Binary for usize



impl Binary for Mode



impl Binary for OFlags

Source

impl Binary for OpCodeFlag



impl Binary for RecvFlags



impl Binary for SendFlags



impl Binary for compio::driver::op::SpliceFlags

Source

impl Binary for bf16

Available on non-SPIR-V only.
Source

impl Binary for f16

Available on non-SPIR-V only.
Source

impl Binary for CipherCtxFlags

Source

impl Binary for CMSOptions

Source

impl Binary for OcspFlag

Source

impl Binary for Pkcs7Flags

Source

impl Binary for ExtensionContext

Source

impl Binary for ShutdownState

Source

impl Binary for SslMode

Source

impl Binary for SslOptions

Source

impl Binary for SslSessionCacheMode

Source

impl Binary for SslVerifyMode

Source

impl Binary for X509CheckFlags

Source

impl Binary for X509VerifyFlags

Source

impl Binary for Z0

Source

impl Binary for UInt<UTerm, B0>

Source

impl Binary for UInt<UTerm, B1>

Source

impl Binary for UTerm



impl Binary for Access



impl Binary for AtFlags



impl Binary for AtFlags



impl Binary for CapabilitiesSecureBits



impl Binary for CapabilitySet



impl Binary for CreateFlags



impl Binary for CreateFlags



impl Binary for DupFlags



impl Binary for EnterFlags



impl Binary for EventFlags



impl Binary for EventfdFlags



impl Binary for FallocateFlags



impl Binary for FdFlags



impl Binary for Flags



impl Binary for Flags



impl Binary for FloatingPointEmulationControl



impl Binary for FloatingPointExceptionMode



impl Binary for FsyncFlags



impl Binary for Gid



impl Binary for IFlags



impl Binary for IoringAcceptFlags



impl Binary for IoringAsyncCancelFlags



impl Binary for IoringCqFlags



impl Binary for IoringCqeFlags



impl Binary for IoringEnterFlags



impl Binary for IoringFeatureFlags



impl Binary for IoringFixedFdFlags



impl Binary for IoringFsyncFlags



impl Binary for IoringMsgringFlags



impl Binary for IoringOpFlags



impl Binary for IoringPollFlags



impl Binary for IoringRecvFlags



impl Binary for IoringRegisterFlags



impl Binary for IoringRsrcFlags



impl Binary for IoringSendFlags



impl Binary for IoringSetupFlags



impl Binary for IoringSqFlags



impl Binary for IoringSqeFlags



impl Binary for IoringTimeoutFlags



impl Binary for IoringUringCmdFlags



impl Binary for MapFlags



impl Binary for MembarrierQuery



impl Binary for MemfdFlags



impl Binary for MlockAllFlags



impl Binary for MlockFlags



impl Binary for MprotectFlags



impl Binary for MremapFlags



impl Binary for MsyncFlags



impl Binary for Pid



impl Binary for PidfdFlags



impl Binary for PidfdGetfdFlags



impl Binary for PipeFlags



impl Binary for PollFlags



impl Binary for PosixSpawnFlags



impl Binary for ProtFlags



impl Binary for ReadFlags



impl Binary for ReadWriteFlags



impl Binary for RecvmsgOutFlags



impl Binary for RenameFlags



impl Binary for ResolveFlags



impl Binary for ReturnFlags



impl Binary for SaFlags



impl Binary for SealFlags



impl Binary for SfdFlags



impl Binary for SocketAddrXdpFlags



impl Binary for SocketFlags



impl Binary for SpeculationFeatureControl



impl Binary for SpeculationFeatureState



impl Binary for SpliceFlags



impl Binary for StatVfsMountFlags



impl Binary for StatxAttributes



impl Binary for StatxFlags



impl Binary for TaggedAddressMode



impl Binary for ThreadNameSpaceType



impl Binary for TimeoutFlags



impl Binary for TimerfdFlags



impl Binary for TimerfdTimerFlags



impl Binary for TxTimeFlags



impl Binary for Uid



impl Binary for UnalignedAccessControl



impl Binary for UnshareFlags



impl Binary for UserfaultfdFlags



impl Binary for WaitFlags



impl Binary for WaitIdOptions



impl Binary for WaitOptions



impl Binary for WaitPidFlag



impl Binary for WaitvFlags



impl Binary for WatchFlags



impl Binary for XattrFlags



impl Binary for XdpDescOptions



impl Binary for XdpOptionsFlags



impl Binary for XdpRingFlags



impl Binary for XdpUmemRegFlags



impl<'a, I> Binary for Format<'a, I>
where I: Iterator, <I as Iterator>::Item: Binary,



impl<'s, T> Binary for SliceVec<'s, T>
where T: Binary,



impl<A> Binary for ArrayVec<A>
where A: Array, <A as Array>::Item: Binary,



impl<A> Binary for TinyVec<A>
where A: Array, <A as Array>::Item: Binary,



impl<O> Binary for I16<O>
where O: ByteOrder,



impl<O> Binary for I32<O>
where O: ByteOrder,



impl<O> Binary for I64<O>
where O: ByteOrder,



impl<O> Binary for I128<O>
where O: ByteOrder,



impl<O> Binary for Isize<O>
where O: ByteOrder,



impl<O> Binary for U16<O>
where O: ByteOrder,



impl<O> Binary for U32<O>
where O: ByteOrder,



impl<O> Binary for U64<O>
where O: ByteOrder,



impl<O> Binary for U128<O>
where O: ByteOrder,



impl<O> Binary for Usize<O>
where O: ByteOrder,

1.0.0 · Source

impl<T> Binary for &T
where T: Binary + ?Sized,

1.0.0 · Source

impl<T> Binary for &mut T
where T: Binary + ?Sized,

1.28.0 · Source

impl<T> Binary for NonZero<T>

1.74.0 · Source

impl<T> Binary for Saturating<T>
where T: Binary,

1.11.0 · Source

impl<T> Binary for Wrapping<T>
where T: Binary,

Source

impl<U> Binary for NInt<U>
where U: Unsigned + NonZero + Binary,

Source

impl<U> Binary for PInt<U>
where U: Unsigned + NonZero + Binary,

Source

impl<U, B> Binary for UInt<UInt<U, B>, B0>
where U: Unsigned, B: Bit, UInt<U, B>: Binary,

Source

impl<U, B> Binary for UInt<UInt<U, B>, B1>
where U: Unsigned, B: Bit, UInt<U, B>: Binary,