Octal

Trait Octal 

1.36.0 · Source
pub trait Octal {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
o formatting.

The Octal trait should format its output as a number in base-8.

For primitive signed integers (i8 to i128, and isize), negative values are formatted as the two’s complement representation.

The alternate flag, #, adds a 0o in front of the output.

For more information on formatters, see the module-level documentation.

Examples

Basic usage with i32:

let x = 42; // 42 is '52' in octal

assert_eq!(format!("{x:o}"), "52");
assert_eq!(format!("{x:#o}"), "0o52");

assert_eq!(format!("{:o}", -16), "37777777760");

Implementing Octal on a type:

use std::fmt;

struct Length(i32);

impl fmt::Octal for Length {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        let val = self.0;

        fmt::Octal::fmt(&val, f) // delegate to i32's implementation
    }
}

let l = Length(9);

assert_eq!(format!("l as octal is: {l:o}"), "l as octal is: 11");

assert_eq!(format!("l as octal is: {l:#06o}"), "l as octal is: 0o0011");

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Implementors

1.0.0 · Source

impl Octal for i8

1.0.0 · Source

impl Octal for i16

1.0.0 · Source

impl Octal for i32

1.0.0 · Source

impl Octal for i64

1.0.0 · Source

impl Octal for i128

1.0.0 · Source

impl Octal for isize

1.0.0 · Source

impl Octal for u8

1.0.0 · Source

impl Octal for u16

1.0.0 · Source

impl Octal for u32

1.0.0 · Source

impl Octal for u64

1.0.0 · Source

impl Octal for u128

1.0.0 · Source

impl Octal for usize



impl Octal for Mode



impl Octal for OFlags

Source

impl Octal for OpCodeFlag



impl Octal for RecvFlags



impl Octal for SendFlags



impl Octal for compio::driver::op::SpliceFlags

Source

impl Octal for bf16

Available on non-SPIR-V only.
Source

impl Octal for f16

Available on non-SPIR-V only.
Source

impl Octal for CipherCtxFlags

Source

impl Octal for CMSOptions

Source

impl Octal for OcspFlag

Source

impl Octal for Pkcs7Flags

Source

impl Octal for ExtensionContext

Source

impl Octal for ShutdownState

Source

impl Octal for SslMode

Source

impl Octal for SslOptions

Source

impl Octal for SslSessionCacheMode

Source

impl Octal for SslVerifyMode

Source

impl Octal for X509CheckFlags

Source

impl Octal for X509VerifyFlags



impl Octal for Access



impl Octal for AtFlags



impl Octal for AtFlags



impl Octal for CapabilitiesSecureBits



impl Octal for CapabilitySet



impl Octal for CreateFlags



impl Octal for CreateFlags



impl Octal for DupFlags



impl Octal for EnterFlags



impl Octal for EventFlags



impl Octal for EventfdFlags



impl Octal for FallocateFlags



impl Octal for FdFlags



impl Octal for Flags



impl Octal for Flags



impl Octal for FloatingPointEmulationControl



impl Octal for FloatingPointExceptionMode



impl Octal for FsyncFlags



impl Octal for Gid



impl Octal for IFlags



impl Octal for IoringAcceptFlags



impl Octal for IoringAsyncCancelFlags



impl Octal for IoringCqFlags



impl Octal for IoringCqeFlags



impl Octal for IoringEnterFlags



impl Octal for IoringFeatureFlags



impl Octal for IoringFixedFdFlags



impl Octal for IoringFsyncFlags



impl Octal for IoringMsgringFlags



impl Octal for IoringOpFlags



impl Octal for IoringPollFlags



impl Octal for IoringRecvFlags



impl Octal for IoringRegisterFlags



impl Octal for IoringRsrcFlags



impl Octal for IoringSendFlags



impl Octal for IoringSetupFlags



impl Octal for IoringSqFlags



impl Octal for IoringSqeFlags



impl Octal for IoringTimeoutFlags



impl Octal for IoringUringCmdFlags



impl Octal for MapFlags



impl Octal for MembarrierQuery



impl Octal for MemfdFlags



impl Octal for MlockAllFlags



impl Octal for MlockFlags



impl Octal for MprotectFlags



impl Octal for MremapFlags



impl Octal for MsyncFlags



impl Octal for Pid



impl Octal for PidfdFlags



impl Octal for PidfdGetfdFlags



impl Octal for PipeFlags



impl Octal for PollFlags



impl Octal for PosixSpawnFlags



impl Octal for ProtFlags



impl Octal for ReadFlags



impl Octal for ReadWriteFlags



impl Octal for RecvmsgOutFlags



impl Octal for RenameFlags



impl Octal for ResolveFlags



impl Octal for ReturnFlags



impl Octal for SaFlags



impl Octal for SealFlags



impl Octal for SfdFlags



impl Octal for SocketAddrXdpFlags



impl Octal for SocketFlags



impl Octal for SpeculationFeatureControl



impl Octal for SpeculationFeatureState



impl Octal for SpliceFlags



impl Octal for StatVfsMountFlags



impl Octal for StatxAttributes



impl Octal for StatxFlags



impl Octal for TaggedAddressMode



impl Octal for ThreadNameSpaceType



impl Octal for TimeoutFlags



impl Octal for TimerfdFlags



impl Octal for TimerfdTimerFlags



impl Octal for TxTimeFlags



impl Octal for Uid



impl Octal for UnalignedAccessControl



impl Octal for UnshareFlags



impl Octal for UserfaultfdFlags



impl Octal for WaitFlags



impl Octal for WaitIdOptions



impl Octal for WaitOptions



impl Octal for WaitPidFlag



impl Octal for WaitvFlags



impl Octal for WatchFlags



impl Octal for XattrFlags



impl Octal for XdpDescOptions



impl Octal for XdpOptionsFlags



impl Octal for XdpRingFlags



impl Octal for XdpUmemRegFlags



impl<'a, I> Octal for Format<'a, I>
where I: Iterator, <I as Iterator>::Item: Octal,



impl<'s, T> Octal for SliceVec<'s, T>
where T: Octal,



impl<A> Octal for ArrayVec<A>
where A: Array, <A as Array>::Item: Octal,



impl<A> Octal for TinyVec<A>
where A: Array, <A as Array>::Item: Octal,



impl<O> Octal for I16<O>
where O: ByteOrder,



impl<O> Octal for I32<O>
where O: ByteOrder,



impl<O> Octal for I64<O>
where O: ByteOrder,



impl<O> Octal for I128<O>
where O: ByteOrder,



impl<O> Octal for Isize<O>
where O: ByteOrder,



impl<O> Octal for U16<O>
where O: ByteOrder,



impl<O> Octal for U32<O>
where O: ByteOrder,



impl<O> Octal for U64<O>
where O: ByteOrder,



impl<O> Octal for U128<O>
where O: ByteOrder,



impl<O> Octal for Usize<O>
where O: ByteOrder,

1.0.0 · Source

impl<T> Octal for &T
where T: Octal + ?Sized,

1.0.0 · Source

impl<T> Octal for &mut T
where T: Octal + ?Sized,

1.28.0 · Source

impl<T> Octal for NonZero<T>

1.74.0 · Source

impl<T> Octal for Saturating<T>
where T: Octal,

1.11.0 · Source

impl<T> Octal for Wrapping<T>
where T: Octal,